metapho.gtkpho.TagViewer

Package metapho :: Module gtkpho :: Class TagViewer |
[hide private]

# Class TagViewer

source code

                            object --+
                                     |
                        metapho.Tagger --+
                                         |
            object --+                   |
                     |                   |
            ??.GObject --+               |
                         |               |
                gtk.Object --+           |
                             |           |
            object --+       |           |
                     |       |           |
    gobject.GInterface --+   |           |
                         |   |           |
      atk.ImplementorIface --+           |
                             |           |
            object --+       |           |
                     |       |           |
    gobject.GInterface --+   |           |
                         |   |           |
             gtk.Buildable --+           |
                             |           |
                    gtk.Widget --+       |
                                 |       |
                     gtk.Container --+   |
                                     |   |
                             gtk.Table --+
                                         |
                                        TagViewer

A PyGTK widget for showing tags.

Instance Methods | [hide private]
__init__(self, parentwin) tagger: an object to manage metapho image tags | source code
change_tag(self, tagno, newstr) Update a tag: called on focus_out from one of the text entries | source code
clear_tags(self, img) | source code
unhighlight_empty_entries(self) Check whether any entries are empty. | source code
focus_none(self) Un-focus any currently focused text entry, leaving nothing focused. | source code
focus_out(self, entry, event, tagno) | source code
toggled(self, button, tagno) | source code
check_entry_tag(focused_widget) At certain times, such as just before exit, the main window may call us to alert us that a tag may have changed. | source code
display_tags(self) Called after read_tags() has been read for all directories. | source code
display_tags_for_category(self, catname) | source code
change_category(self, combobox) The callback when the combobox is changed by the user | source code
next_category(self, howmany) Advance to the next category (if howmany==1) or some other category. | source code
show_category_by_number(self, catno) Show a specific category by number. | source code
edit_categories(self, w) | source code
highlight_tag(self, tagno, val) Turn tag number tagno on (if val=True) or off (val=False). | source code
show_matches(self, pat) Colorize any tags that match the given pattern. | source code
focus_first_match(self, pat) Focus the first text field matching the pattern. | source code
set_image(self, img) | source code
add_tag(self, tag, img) Add a tag to the given image. | source code
remove_tag(self, tag, img) | source code
toggle_tag(self, tagno, img) Toggle tag number tagno for the given img. | source code
toggle_tag_by_letter(self, tagchar, img) Toggle the tag corresponding to the letter typed by the user | source code
focus_next_entry(self) Set focus to the next available entry. | source code
Inherited from `metapho.Tagger`: `__repr__`, `match_tag`, `process_tag`, `read_tags`, `rename_category`, `write_tag_file` Inherited from `gtk.Table`: `__iter__`, `attach`, `attach_defaults`, `get_col_spacing`, `get_default_col_spacing`, `get_default_row_spacing`, `get_homogeneous`, `get_row_spacing`, `resize`, `set_col_spacing`, `set_col_spacings`, `set_homogeneous`, `set_row_spacing`, `set_row_spacings` Inherited from `gtk.Container`: `__len__`, `__nonzero__`, `add`, `add_with_properties`, `check_resize`, `child_get`, `child_get_property`, `child_set`, `child_set_property`, `child_type`, `children`, `do_add`, `do_check_resize`, `do_child_type`, `do_composite_name`, `do_forall`, `do_get_child_property`, `do_remove`, `do_set_child_property`, `do_set_focus_child`, `forall`, `foreach`, `get_border_width`, `get_children`, `get_focus_chain`, `get_focus_child`, `get_focus_hadjustment`, `get_focus_vadjustment`, `get_resize_mode`, `install_child_property`, `list_child_properties`, `propagate_expose`, `remove`, `resize_children`, `set_border_width`, `set_focus_chain`, `set_focus_child`, `set_focus_hadjustment`, `set_focus_vadjustment`, `set_reallocate_redraws`, `set_resize_mode`, `unset_focus_chain` Inherited from `gtk.Widget`: `activate`, `add_accelerator`, `add_events`, `add_mnemonic_label`, `can_activate_accel`, `child_focus`, `child_notify`, `class_path`, `create_pango_context`, `create_pango_layout`, `destroy`, `do_button_press_event`, `do_button_release_event`, `do_can_activate_accel`, `do_client_event`, `do_composited_changed`, `do_configure_event`, `do_delete_event`, `do_destroy_event`, `do_direction_changed`, `do_drag_begin`, `do_drag_data_delete`, `do_drag_data_get`, `do_drag_data_received`, `do_drag_drop`, `do_drag_end`, `do_drag_leave`, `do_drag_motion`, `do_enter_notify_event`, `do_event`, `do_expose_event`, `do_focus`, `do_focus_in_event`, `do_focus_out_event`, `do_get_accessible`, `do_grab_broken_event`, `do_grab_focus`, `do_grab_notify`, `do_hide`, `do_hide_all`, `do_hierarchy_changed`, `do_key_press_event`, `do_key_release_event`, `do_leave_notify_event`, `do_map`, `do_map_event`, `do_mnemonic_activate`, `do_motion_notify_event`, `do_no_expose_event`, `do_parent_set`, `do_popup_menu`, `do_property_notify_event`, `do_proximity_in_event`, `do_proximity_out_event`, `do_realize`, `do_screen_changed`, `do_scroll_event`, `do_selection_clear_event`, `do_selection_get`, `do_selection_notify_event`, `do_selection_received`, `do_selection_request_event`, `do_show`, `do_show_all`, `do_show_help`, `do_size_allocate`, `do_size_request`, `do_state_changed`, `do_style_set`, `do_unmap`, `do_unmap_event`, `do_unrealize`, `do_visibility_notify_event`, `do_window_state_event`, `drag_begin`, `drag_check_threshold`, `drag_dest_add_image_targets`, `drag_dest_add_text_targets`, `drag_dest_add_uri_targets`, `drag_dest_find_target`, `drag_dest_get_target_list`, `drag_dest_get_track_motion`, `drag_dest_set`, `drag_dest_set_proxy`, `drag_dest_set_target_list`, `drag_dest_set_track_motion`, `drag_dest_unset`, `drag_get_data`, `drag_highlight`, `drag_source_add_image_targets`, `drag_source_add_text_targets`, `drag_source_add_uri_targets`, `drag_source_get_target_list`, `drag_source_set`, `drag_source_set_icon`, `drag_source_set_icon_name`, `drag_source_set_icon_pixbuf`, `drag_source_set_icon_stock`, `drag_source_set_target_list`, `drag_source_unset`, `drag_unhighlight`, `draw`, `ensure_style`, `error_bell`, `event`, `freeze_child_notify`, `get_accessible`, `get_action`, `get_activate_signal`, `get_allocation`, `get_ancestor`, `get_app_paintable`, `get_can_default`, `get_can_focus`, `get_child_requisition`, `get_child_visible`, `get_clipboard`, `get_colormap`, `get_composite_name`, `get_direction`, `get_display`, `get_double_buffered`, `get_events`, `get_extension_events`, `get_has_tooltip`, `get_has_window`, `get_mapped`, `get_modifier_style`, `get_name`, `get_no_show_all`, `get_pango_context`, `get_parent`, `get_parent_window`, `get_pointer`, `get_realized`, `get_receives_default`, `get_requisition`, `get_root_window`, `get_screen`, `get_sensitive`, `get_settings`, `get_size_request`, `get_snapshot`, `get_state`, `get_style`, `get_tooltip_markup`, `get_tooltip_text`, `get_tooltip_window`, `get_toplevel`, `get_visible`, `get_visual`, `get_window`, `grab_add`, `grab_default`, `grab_focus`, `grab_remove`, `has_default`, `has_focus`, `has_grab`, `has_rc_style`, `has_screen`, `hide`, `hide_all`, `hide_on_delete`, `input_shape_combine_mask`, `intersect`, `is_ancestor`, `is_composited`, `is_drawable`, `is_focus`, `is_sensitive`, `is_toplevel`, `keynav_failed`, `list_accel_closures`, `list_mnemonic_labels`, `map`, `menu_get_for_attach_widget`, `mnemonic_activate`, `modify_base`, `modify_bg`, `modify_cursor`, `modify_fg`, `modify_font`, `modify_style`, `modify_text`, `path`, `queue_clear`, `queue_clear_area`, `queue_draw`, `queue_draw_area`, `queue_resize`, `queue_resize_no_redraw`, `rc_get_style`, `realize`, `region_intersect`, `remove_accelerator`, `remove_mnemonic_label`, `render_icon`, `reparent`, `reset_rc_styles`, `reset_shapes`, `selection_add_target`, `selection_add_targets`, `selection_clear_targets`, `selection_convert`, `selection_owner_set`, `selection_remove_all`, `send_expose`, `send_focus_change`, `set_accel_path`, `set_activate_signal`, `set_allocation`, `set_app_paintable`, `set_can_default`, `set_can_focus`, `set_child_visible`, `set_colormap`, `set_composite_name`, `set_direction`, `set_double_buffered`, `set_events`, `set_extension_events`, `set_has_tooltip`, `set_has_window`, `set_mapped`, `set_name`, `set_no_show_all`, `set_parent`, `set_parent_window`, `set_realized`, `set_receives_default`, `set_redraw_on_allocate`, `set_scroll_adjustments`, `set_sensitive`, `set_set_scroll_adjustments_signal`, `set_size_request`, `set_state`, `set_style`, `set_tooltip_markup`, `set_tooltip_text`, `set_tooltip_window`, `set_uposition`, `set_usize`, `set_visible`, `set_window`, `shape_combine_mask`, `show`, `show_all`, `show_now`, `size_allocate`, `size_request`, `style_attach`, `style_get_property`, `thaw_child_notify`, `translate_coordinates`, `trigger_tooltip_query`, `unmap`, `unparent`, `unrealize` Inherited from `gtk.Object`: `do_destroy`, `flags`, `remove_data`, `remove_no_notify`, `set_flags`, `unset_flags` Inherited from `unreachable.GObject`: `__copy__`, `__deepcopy__`, `__delattr__`, `__eq__`, `__gdoc__`, `__ge__`, `__gobject_init__`, `__gt__`, `__hash__`, `__le__`, `__lt__`, `__ne__`, `__new__`, `__setattr__`, `chain`, `connect`, `connect_after`, `connect_object`, `connect_object_after`, `disconnect`, `disconnect_by_func`, `emit`, `emit_stop_by_name`, `freeze_notify`, `get_data`, `get_properties`, `get_property`, `handler_block`, `handler_block_by_func`, `handler_disconnect`, `handler_is_connected`, `handler_unblock`, `handler_unblock_by_func`, `notify`, `props`, `set_data`, `set_properties`, `set_property`, `stop_emission`, `thaw_notify`, `weak_ref` Inherited from `atk.ImplementorIface`: `ref_accessible` Inherited from `gtk.Buildable`: `add_child`, `construct_child`, `do_add_child`, `do_construct_child`, `do_get_internal_child`, `do_parser_finished`, `do_set_name`, `get_internal_child`, `parser_finished` Inherited from `object`: `__format__`, `__getattribute__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `gtk.Table`: `__gtype__`

Instance Variables | [hide private]
Inherited from `metapho.Tagger`: `commondir`

Properties | [hide private]
Inherited from `gtk.Container`: `border_width`, `focus_child`, `has_focus_chain`, `need_resize`, `reallocate_redraws`, `resize_mode` Inherited from `gtk.Widget`: `allocation`, `name`, `parent`, `requisition`, `saved_state`, `state`, `style`, `window` Inherited from `unreachable.GObject`: `__grefcount__` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, parentwin) (Constructor) | source code
tagger: an object to manage metapho image tags Overrides: object.__init__ (inherited documentation)

### clear_tags(self, img) | source code
Overrides: metapho.Tagger.clear_tags

### unhighlight_empty_entries(self) | source code
Check whether any entries are empty. If so, make sure they're unhighlighted.

### focus_none(self) | source code
Un-focus any currently focused text entry, leaving nothing focused. If there was a focused entry and it was empty, de-select the corresponding toggle button.

### check_entry_tag(focused_widget) | source code
At certain times, such as just before exit, the main window may call us to alert us that a tag may have changed. We need to find out which entry contains it and check the tag.

### show_category_by_number(self, catno) | source code
Show a specific category by number. Raises IndexError if catno is out of range.

### show_matches(self, pat) | source code
Colorize any tags that match the given pattern. If pat == None, un-colorize everything.

### add_tag(self, tag, img) | source code
Add a tag to the given image. img is a metapho.Image. tag may be a string, which can be a new string or an existing one, or an integer index into the tag list. Return the index (in the global tags list) of the tag just added, or None if error. Overrides: metapho.Tagger.add_tag

### remove_tag(self, tag, img) | source code
Overrides: metapho.Tagger.remove_tag

### toggle_tag(self, tagno, img) | source code
Toggle tag number tagno for the given img. Overrides: metapho.Tagger.toggle_tag

### focus_next_entry(self) | source code
Set focus to the next available entry. If we're already typing in a new tag entry that hasn't been saved yet, save it first before switching to the new one.